--Neoloader registration
local lme_flag = false
if type(lib) == "table" and lib[0] == "LME" then
	if not lib.is_exist("url snatcher", "0") then
		lib.register("plugins/url snatcher/snatcher.ini")
	end
	
	if not lib.is_ready("url snatcher", "0") then
		return
	end
	
	if lib.is_ready("SCO") then
		print("Notice: URL Snatcher and Stellar Chat Overhaul")
		print("Stellar Chat Overhaul includes the functionality of URL Snatcher, offering enhanced features. As Stellar Chat Overhaul is currently installed and active, it is recommended you disable or remove URL Snatcher from your game to avoid redundancy.")
		lib.log_error("Stellar Chat Overhaul includes the functionality of URL Snatcher, offering enhanced features. As Stellar Chat Overhaul is currently installed and active, it is recommended you disable or remove URL Snatcher from your game to avoid redundancy.", 3, "url snatcher", "0")
	end
	
	lme_flag = true
end

local config = {
	echo_catches = "YES",
}

for k, v in pairs(config) do
	config[k] = gkini.ReadString("url snatcher", k, v)
end

local extract_http_links = function(input)
	if type(input) ~= "string" then
		return {tostring(input)}
	end
	
    local result = {input}  -- Start with the input string as the first element of the result table
    for link in string.gmatch(input, "http[%w%.%-_/%%?&=:#]+") do
        table.insert(result, link)
    end
    --return table.unpack(result)  -- Return the elements of the result table as individual return values.
	return result
end

local link_store = {}

local event_handler = function(self, event, data, ...)
	local args = {...}
	if type(data) == "table" then
		for k, v in pairs(data) do
			args[k] = v
		end
	else
		table.insert(args, data)
	end
	args.event = event or {}
	
	local urltab = extract_http_links(args.event.msg or args.msg or "")
	
	if #urltab < 2 then
		return
	end
	
	for i, v in ipairs(urltab) do
		if i > 1 then
			if config.echo_catches == "YES" then
				print("\127295D43URL:  " .. v)
			end
			
			table.insert(link_store, v)
		end
	end
end

local event_table = {
	"CHAT_MSG_MOTD",
	"CHAT_MSG_ERROR",
	"CHAT_MSG_PRINT",
	"CHAT_MSG_PRIVATE",
	"CHAT_MSG_CHANNEL_EMOTE",
	"CHAT_MSG_CHANNEL",
	"CHAT_MSG_CHANNEL_EMOTE_ACTIVE",
	"CHAT_MSG_CHANNEL_ACTIVE",
	"CHAT_MSG_SECTOR_EMOTE",
	"CHAT_MSG_SECTOR",
	"CHAT_MSG_NATION",
	"CHAT_MSG_GUILD_EMOTE",
	"CHAT_MSG_GUILD",
	"CHAT_MSG_GUILD_MOTD",
	"CHAT_MSG_GUIDE",
	"CHAT_MSG_GROUP",
	"CHAT_MSG_GROUP_NOTIFICATION",
	"CHAT_MSG_SYSTEM",
	"CHAT_MSG_BUDDYNOTE",
	"CHAT_MSG_INCOMINGBUDDYNOTE",
}

for k, v in ipairs(event_table) do
	RegisterEvent(event_handler, v)
end







local create_ui = function()
	local url_index = 0
	local url_select = "http://www.vendetta-online.com/"
	
	local entry_select = iup.stationsublist {
		action = function(self, t, i, cv)
			if cv == 1 then
				url_index = i
				url_select = t
			end
		end,
		size = "HALFxHALF",
	}
	
	for k, v in ipairs(link_store) do
		entry_select[k] = v
	end
	
	local diag = iup.dialog {
		topmost = "YES",
		fullscreen = "YES",
		bgcolor = "0 0 0 200 *",
		alignment = "ACENTER",
		iup.vbox {
			iup.fill { },
			iup.hbox {
				iup.fill { },
				iup.stationsubframe {
					size = "%55x%55",
					iup.vbox {
						iup.fill {
							size = "%2",
						},
						iup.hbox {
							iup.fill { },
							iup.label {
								title = "URLs caught in chat: ",
							},
							iup.fill { },
							iup.stationbutton {
								title = "Close",
								action = function(self)
									HideDialog(iup.GetDialog(self))
									iup.GetDialog(self):destroy()
								end,
							},
						},
						entry_select,
						iup.hbox {
							iup.stationbutton {
								title = "Open selected URL",
								size = "HALFx",
								action = function()
									Game.OpenWebBrowser(url_select)
								end,
							},
						},
						iup.fill {
							size = "%2",
						},
					},
				},
				iup.fill { },
			},
			iup.fill { },
		},
	}
	
	diag:map()
	ShowDialog(diag)
end

RegisterUserCommand("url", create_ui)
RegisterUserCommand("urlsnatcher", create_ui)